@@ -29,19 +29,33 @@ const char *Checks::chkJoin(Line *line, ScriptImage *img)
 		return "join has no members";
 
 	return NULL;
-}	
+}
+
+const char *Checks::chkConnect(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+	
+	if(!useKeywords(line, "=session=caller=display=timeout=duration=tone"))
+		return "invalid keyword used for connect";
+
+	if(!getOption(line, &idx))
+		return "missing dial option";
+
+	if(!getOption(line, &idx))
+		return NULL;
+
+	if(getOption(line, &idx))
+		return "too many arguments for connect";
+
+	return NULL;
+}
 
 const char *Checks::chkStart(Line *line, ScriptImage *img)
 {
         unsigned idx = 0;
 	const char *cp;
 
-	if(!stricmp(line->cmd, "connect"))
-		cp = "=session=caller=display=timeout=duration=tone";
-	else
-		cp = "=session=caller=display";
-
-        if(!useKeywords(line, cp))
+        if(!useKeywords(line, "=session=caller=display"))
                 return "invalid keyword used for start";
 
         if(!getOption(line, &idx))
