@@ -589,7 +589,7 @@ public:
 	 * This is a class used for collecting statistics for call 
 	 * traffic measurement, such as might be used by MRTG.
 	 */
-	class Traffic
+	class __EXPORT Traffic
 	{
 	private:
 		static unsigned long stamp;
