@@ -20,8 +20,8 @@ using namespace ost;
 using namespace std;
 
 BayonneMsgport::BayonneMsgport(BayonneDriver *driver) :
-Buffer(atoi(driver->getLast("events"))), 
-Thread(atoi(driver->getLast("priority")), atoi(driver->getLast("stack")) * 1024) 
+Thread(atoi(driver->getLast("priority")), atoi(driver->getLast("stack")) * 1024),
+Buffer(atoi(driver->getLast("events")))
 {
 	unsigned size = atoi(driver->getLast("events"));
 
@@ -164,6 +164,8 @@ void BayonneMsgport::run(void)
 		{
 		case MSGPORT_SHUTDOWN:
 			Thread::sync();
+		default:
+			break;
 		}
 
 		session = getSession(event.timeslot);
