@@ -317,6 +317,9 @@ release:
 
 bool BayonneSession::stateStart(Event *event)
 {
+	Event cancel;
+	BayonneSession *s;
+
 	if(enterTone(event))
 		return true;
 
@@ -336,6 +339,13 @@ bool BayonneSession::stateStart(Event *event)
 			error("start-failed");
 		setRunning();
 		return true;
+	case TIMER_EXPIRED:
+		memset(&event, 0, sizeof(event));
+		cancel.id = CANCEL_CHILD;
+		cancel.pid = this;
+		s = getSid(state.tone.sessionid);
+		if(s)
+			s->queEvent(&cancel);		
 	case CHILD_EXPIRED:
 		if(!scriptEvent("start:expired"))
 			error("start-expired");
@@ -906,31 +916,38 @@ bool BayonneSession::stateConnect(Event *event)
 failed:
         case STOP_PARENT:
         case CHILD_FAILED:
-                if(!scriptEvent("start:failed"))
-                        error("start-failed");
+                if(!scriptEvent("dial:failed"))
+                        error("dial-failed");
                 setRunning();
                 return true;
 	case CHILD_INVALID:
-		if(!scriptEvent("start:invalid"))
-			error("start-invalid");
+		if(!scriptEvent("dial:invalid"))
+			error("dial-invalid");
 		setRunning();
 		return true;
+        case TIMER_EXPIRED:
+                memset(&event, 0, sizeof(event));
+                cancel.id = CANCEL_CHILD;
+                cancel.pid = this;
+                s = getSid(state.tone.sessionid);
+                if(s)
+                        s->queEvent(&cancel);
         case CHILD_EXPIRED:
-                if(!scriptEvent("start:noanswer"))
-                        error("start-noanswer");
+                if(!scriptEvent("dial:noanswer"))
+                        error("dial-noanswer");
                 setRunning();
                 return true;
         case CHILD_BUSY:
-                if(!scriptEvent("start:busy"))
-                        error("start-busy");
+                if(!scriptEvent("dial:busy"))
+                        error("dial-busy");
                 return true;
 	case CHILD_DND:
-		if(!scriptEvent("start:dnd"))
-			error("start-dnd");
+		if(!scriptEvent("dial:dnd"))
+			error("dial-dnd");
 		return true;
 	case CHILD_FAX:
-		if(!scriptEvent("start:fax"))
-			error("start-fax");
+		if(!scriptEvent("dial:fax"))
+			error("dial-fax");
 		return true;
         case PEER_WAITING:
 		s = getSid(state.tone.sessionid);
@@ -956,13 +973,6 @@ failed:
                         s->queEvent(&cancel);
 	default:
 		return enterCommon(event);
-	case TIMER_EXPIRED:
-		memset(&cancel, 0, sizeof(cancel));
-		cancel.id = CANCEL_CHILD;
-		s = getSid(state.tone.sessionid);
-		if(s)
-			s->queEvent(&cancel);		
-		return false;
         }
 }
 
@@ -2071,7 +2081,7 @@ bool BayonneSession::filterPosting(Event *event)
 	case DETACH_CHILD:
 		Thread::yield();
 		pid = getSid(var_pid);
-		if(!pid || pid != event->pid)
+		if(pid && pid != event->pid)
 			return false;
 		strcpy(var_pid, "none");
 	default:
