@@ -162,6 +162,8 @@ public:
 	bool getAuthentication(Session *s, osip_message_t *response);
 	bool isExternal(const char *ext);
 	bool isReachable(const char *proxy);
+	bool isRegistered(const char *ext);
+	bool isAvailable(const char *ext);
 
 	void run(void);
 
@@ -218,6 +220,7 @@ public:
         void run(void);
 	void peerAudio(Encoded encoded, bool linear);
 	void postAudio(Encoded encoded);
+	void syncAudio(void);
 
         void setSource(AudioBase *get, timeout_t max = 0);
         void setSink(AudioBase *put, timeout_t max = 0);
