@@ -588,7 +588,11 @@ failure:
 	case CALL_RINGING:
 		stopTimer();
 		return true;
+	case STOP_SCRIPT:
+	case STOP_DISCONNECT:
 	case TIMER_EXPIRED:
+	case CANCEL_CHILD:
+		sipHangup();
 		offhook = false;
 	default:
 		return false;
