@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <ctype.h>
 
 int main(int argc, char **argv)
 {
@@ -7,8 +8,7 @@ int main(int argc, char **argv)
 
 	for(;;)
 	{
-		fgets(lbuf, sizeof(lbuf), stdin);
-		if(feof(stdin))
+		if(!fgets(lbuf, sizeof(lbuf), stdin) || feof(stdin))
 			break;
 		if(!isalnum(lbuf[0]))
 			break;
